@@ -5,6 +5,7 @@ use ockam_core::{AsyncTryClone, Result};
 use ockam_key_exchange_core::NewKeyExchanger;
 
 /// Represents an XX NewKeyExchanger
+#[derive(AsyncTryClone)]
 pub struct XXNewKeyExchanger<V: XXVault> {
     vault: V,
 }
@@ -16,15 +17,6 @@ impl<V: XXVault> XXNewKeyExchanger<V> {
     }
 }
 
-#[async_trait]
-impl<V: XXVault> AsyncTryClone for XXNewKeyExchanger<V> {
-    async fn async_try_clone(&self) -> Result<Self> {
-        Ok(Self {
-            vault: self.vault.async_try_clone().await?,
-        })
-    }
-}
-
 #[async_trait]
 impl<V: XXVault> NewKeyExchanger for XXNewKeyExchanger<V> {
     type Initiator = Initiator<V>;
